@@ -1,7 +1,6 @@
 #################################################################################
 ##
-##   R package rugarch by Alexios Ghalanos Copyright (C) 2008, 2009, 2010, 2011, 
-##	 2012
+##   R package rugarch by Alexios Ghalanos Copyright (C) 2008-2013.
 ##   This file is part of the R package rugarch.
 ##
 ##   The R package rugarch is free software: you can redistribute it and/or modify
@@ -74,9 +73,8 @@ setClass("uGARCHpath",
 #----------------------------------------------------------------------------------
 setClass("GARCHroll", contains = c("rGARCH", "VIRTUAL"))
 setClass("uGARCHroll",
-		representation(roll = "vector",
-				forecast = "vector",
-				model = "vector"),
+		representation(model = "vector",
+				forecast = "vector"),
 		contains = "GARCHroll")
 #----------------------------------------------------------------------------------
 # univariate garch parameter distribution (by simulation)
