@@ -48,10 +48,10 @@
 	n = length(xdata$data)
 	if((n-n.start)<100) stop("\nugarchfit-->error: function requires at least 100 data\n points to run\n")
 	data = xdata$data[1:(n-n.start)]
-	dates = xdata$pos[1:(n-n.start)]
+	index = xdata$index[1:(n-n.start)]
 	origdata = xdata$data
-	origdates = xdata$pos
-	dformat = xdata$dformat
+	origindex = xdata$index
+	period = xdata$period
 	# arglist replaces the use of custom environments (resolves the problem of 
 	# non-shared environment in parallel estimation, particularly windows)
 	garchenv = new.env(hash = TRUE)
@@ -73,7 +73,7 @@
 	} else{
 		vexdata = NULL
 	}
-	arglist$dates = dates
+	arglist$index = index
 	arglist$trace = trace
 	m =  model$maxOrder
 	model$modeldata$T = T = length(as.numeric(data))
@@ -102,7 +102,7 @@
 				# if all parameters are fixed an no standard erros are to
 				# be calculated then we return a ugarchfilter object
 				cat("\nugarchfit-->warning: all parameters fixed...returning ugarchfilter object instead\n")
-				return(ugarchfilter(data = data, spec = spec, out.sample = out.sample))
+				return(ugarchfilter(data = xts(origdata, origindex), spec = spec, out.sample = out.sample))
 			} else{
 				# if all parameters are fixed but we require standard errors, we
 				# skip the solver
@@ -199,8 +199,8 @@
 				hess, arglist = arglist)
 		model$modelinc[7] = modelinc[7]
 		model$modeldata$data = origdata
-		model$modeldata$dates = origdates
-		model$modeldata$date.format = dformat
+		model$modeldata$index = origindex
+		model$modeldata$period = period
 		model$pars[, 1] = fit$ipars[,1]
 		model$pars[, 5:6] = ipars2[,5:6]
 		fit$ipars[, 4] = ipars2[, 4]
@@ -213,8 +213,8 @@
 		fit$message = sol$message
 		fit$convergence = 1
 		model$modeldata$data = origdata
-		model$modeldata$dates = origdates
-		model$modeldata$date.format = dformat
+		model$modeldata$index = origindex
+		model$modeldata$period = period
 	}
 	
 	# make model list to return some usefule information which
@@ -353,13 +353,13 @@
 	# no forward looking information contaminating the study.
 	xdata = .extractdata(data)
 	data = xdata$data
-	dates = xdata$pos
-	dformat = xdata$dformat
+	index = xdata$index
+	period = xdata$period
 	origdata = data
-	origdates = dates
+	origindex = index
 	T = length(origdata)  - out.sample
 	data = origdata[1:T]
-	dates = origdates[1:T]
+	index = origindex[1:T]
 	if(!is.null(n.old)) Nx = n.old else Nx = length(data)
 	recinit = .checkrec(rec.init, Nx)
 	model = spec@model
@@ -435,10 +435,9 @@
 	filter$distribution = distribution
 	filter$ipars = ipars
 	model$modeldata$data = origdata
-	model$modeldata$dates = origdates
-	model$modeldata$date.format = dformat
+	model$modeldata$index = origindex
+	model$modeldata$period = period
 	model$n.start = out.sample
-	
 	sol = new("uGARCHfilter",
 			filter = filter,
 			model = model)
@@ -451,11 +450,11 @@
 .egarchforecast = function(fitORspec, data = NULL, n.ahead = 10, n.roll = 0, out.sample = 0, 
 		external.forecasts = list(mregfor = NULL, vregfor = NULL), ...)
 {
-	fit = fitORspec
-	data = fit@model$modeldata$data
-	Nor = length(as.numeric(data))
-	dates = fit@model$modeldata$dates
-	dformat = fit@model$modeldata$date.format
+	fit    = fitORspec
+	data   = fit@model$modeldata$data
+	Nor    = length(as.numeric(data))
+	index  = fit@model$modeldata$index
+	period = fit@model$modeldata$period
 	ns = fit@model$n.start
 	N = Nor - ns
 	model = fit@model
@@ -467,7 +466,7 @@
 	pars = fit@fit$coef
 	ipars = fit@fit$ipars
 	# check if necessary the external regressor forecasts provided first
-	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, ipars, n.ahead, Nor, out.sample = ns, n.roll)
+	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, n.ahead, Nor, out.sample = ns, n.roll)
 	mxf = xreg$mxf
 	vxf = xreg$vxf
 	
@@ -480,16 +479,19 @@
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
 					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]), 
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
-	tmp =  data.frame(data[1:(N + fcreq)])
-	rownames(tmp) = as.character(dates[1:(N + fcreq)])
-	flt = .egarchfilter(data = tmp[,1,drop=FALSE], spec = fspec, n.old = N)
+	tmp =  xts(data[1:(N + fcreq)], index[1:(N + fcreq)])
+	flt = .egarchfilter(data = tmp, spec = fspec, n.old = N)
 	sigmafilter = flt@filter$sigma
 	resfilter = flt@filter$residuals
 	zfilter = flt@filter$z
-	
 	kappa = egarchKappa(ipars[idx["ghlambda",1],1], ipars[idx["shape",1],1], ipars[idx["skew",1],1], distribution)
-	forecasts = vector(mode="list", length = n.roll+1)
-	fwdd = vector(mode="list", length = n.roll+1)
+	# forecast GARCH process
+	seriesFor = sigmaFor = matrix(NA, ncol = n.roll+1, nrow = n.ahead)
+	#seriesFor[1,] = fitted(flt)[(N+1):(N+n.roll+1)]
+	#sigmaFor[1,]  = sigma(flt)[(N+1):(N+n.roll+1)]
+	# n.ahead x n.roll +1 (n.ahead=1 generted by model)
+	colnames(seriesFor) = colnames(sigmaFor) = as.character(index[N:(N+n.roll)])
+	rownames(seriesFor) = rownames(sigmaFor) = paste("T+", 1:n.ahead, sep="")
 	for(i in 1:(n.roll+1)){
 		np = N + i - 1
 		if(modelinc[1] > 0){
@@ -497,11 +499,7 @@
 		} else{
 			mu = rep(0, N+i+n.ahead-1)
 		}
-		#if(modelinc[7]>0){
-			omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
-		#} else {
-		#	omega = rep(0, N+i+n.ahead-1)
-		#}
+		omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
 		# no look-ahead
 		h = c(sigmafilter[1:(N+i-1)], rep(0, n.ahead))
 		epsx = c(resfilter[1:(N+i-1)], rep(0, n.ahead))
@@ -511,11 +509,8 @@
 		mxfi = mxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		vxfi = vxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		ans = .negarchforecast(ipars, modelinc, idx, mu, omega, kappa, mxfi, vxfi, h, epsx, z, data = x, N = np, n.ahead)
-		
-		fdf = data.frame(sigma = ans$h, series = ans$x)
-		fwdd[[i]] = .forcdates( dates, n.ahead, N, i, ns, dformat )
-		rownames(fdf) = as.character(fwdd[[i]])
-		forecasts[[i]] = fdf
+		sigmaFor[,i] = ans$h
+		seriesFor[,i] = ans$x
 	}
 	
 	fcst = list()
@@ -523,8 +518,8 @@
 	fcst$N = N+ns
 	fcst$n.start = ns
 	fcst$n.roll = n.roll
-	fcst$forecasts = forecasts
-	fcst$fdates = fwdd
+	fcst$sigmaFor = sigmaFor
+	fcst$seriesFor = seriesFor
 	model$modeldata$sigma = flt@filter$sigma
 	model$modeldata$residuals = flt@filter$residuals
 	ans = new("uGARCHforecast",
@@ -578,13 +573,14 @@
 	Nor = length(as.numeric(xdata$data))
 	data = xdata$data
 	N = length(as.numeric(data))
-	dates = xdata$pos
-	dformat = xdata$dformat	
+	index = xdata$index
+	period = xdata$period
+	model = spec@model
 	ns = out.sample
 	if( n.roll > ns ) stop("\nugarchforecast-->error: n.roll must not be greater than out.sample!")
 	N = Nor - ns
+	distribution = model$modeldesc$distribution
 	
-	model = spec@model
 	ipars = model$pars
 	pars = unlist(model$fixed.pars)
 	parnames = names(pars)
@@ -603,12 +599,11 @@
 	ipars = model$pars
 	modelinc = model$modelinc
 	model$modeldata$data = data
-	model$modeldata$dates = dates
-	model$modeldata$dformat = dformat
-	distribution = model$modeldesc$distribution
+	model$modeldata$index = index
+	model$modeldata$period = period
 	
 	# check if necessary the external regressor forecasts provided first
-	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, ipars, n.ahead, Nor, out.sample = ns, n.roll)
+	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, n.ahead, Nor, out.sample = ns, n.roll)
 	mxf = xreg$mxf
 	vxf = xreg$vxf
 	
@@ -622,16 +617,19 @@
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
 					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]), 
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
-	tmp =  data.frame(data[1:(N + fcreq)])
-	rownames(tmp) = as.character(dates[1:(N + fcreq)])
-	flt = .egarchfilter(data = tmp[,1,drop=FALSE], spec = fspec, n.old = N)
+	tmp =  xts(data[1:(N + fcreq)], index[1:(N + fcreq)])
+	flt = .egarchfilter(data = tmp, spec = fspec, n.old = N)
 	sigmafilter = flt@filter$sigma
 	resfilter = flt@filter$residuals
 	zfilter = flt@filter$z
 	kappa = egarchKappa(ipars[idx["ghlambda",1],1], ipars[idx["shape",1],1], ipars[idx["skew",1],1], distribution)
-	
-	forecasts = vector(mode="list", length = n.roll+1)
-	fwdd = vector(mode="list", length = n.roll+1)
+	# forecast GARCH process
+	seriesFor = sigmaFor = matrix(NA, ncol = n.roll+1, nrow = n.ahead)
+	#seriesFor[1,] = fitted(flt)[(N+1):(N+n.roll+1)]
+	#sigmaFor[1,]  = sigma(flt)[(N+1):(N+n.roll+1)]
+	# n.ahead x n.roll +1 (n.ahead=1 generted by model)
+	colnames(seriesFor) = colnames(sigmaFor) = as.character(index[N:(N+n.roll)])
+	rownames(seriesFor) = rownames(sigmaFor) = paste("T+", 1:n.ahead, sep="")
 	for(i in 1:(n.roll+1)){
 		np = N + i - 1
 		if(modelinc[1] > 0){
@@ -639,11 +637,7 @@
 		} else{
 			mu = rep(0, N+i+n.ahead-1)
 		}
-		#if(modelinc[7]>0){
-			omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
-		#} else {
-		#	omega = rep(0, N+i+n.ahead-1)
-		#}
+		omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
 		# no look-ahead
 		h = c(sigmafilter[1:(N+i-1)], rep(0, n.ahead))
 		epsx = c(resfilter[1:(N+i-1)], rep(0, n.ahead))
@@ -653,19 +647,16 @@
 		mxfi = mxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		vxfi = vxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		ans = .negarchforecast(ipars, modelinc, idx, mu, omega, kappa, mxfi, vxfi, h, epsx, z, data = x, N = np, n.ahead)
-		
-		fdf = data.frame(sigma = ans$h, series = ans$x)
-		fwdd[[i]] = .forcdates( dates, n.ahead, N, i, ns, dformat )
-		rownames(fdf) = as.character(fwdd[[i]])
-		forecasts[[i]] = fdf
+		sigmaFor[,i] = ans$h
+		seriesFor[,i] = ans$x
 	}
 	fcst = list()
 	fcst$n.ahead = n.ahead
 	fcst$N = N+ns
 	fcst$n.start = ns
 	fcst$n.roll = n.roll
-	fcst$forecasts = forecasts
-	fcst$fdates = fwdd
+	fcst$sigmaFor = sigmaFor
+	fcst$seriesFor = seriesFor
 	model$modeldata$sigma = flt@filter$sigma
 	model$modeldata$residuals = flt@filter$residuals
 	ans = new("uGARCHforecast",
@@ -679,7 +670,7 @@
 .egarchsim = function(fit, n.sim = 1000, n.start = 0, m.sim = 1, startMethod = 
 				c("unconditional","sample"), presigma = NA, prereturns = NA, 
 		preresiduals = NA, rseed = NA, custom.dist = list(name = NA, distfit = NA), 
-		mexsimdata = NULL, vexsimdata = NULL)
+		mexsimdata = NULL, vexsimdata = NULL, ...)
 {
 	if( (n.sim+n.start) < 100 && m.sim > 100 ){
 		ans = .egarchsim2(fit = fit, n.sim = n.sim, n.start = n.start, m.sim = m.sim, 
@@ -730,7 +721,7 @@
 	distribution = model$modeldesc$distribution
 	
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 	kappa = egarchKappa(ipars[idx["ghlambda",1],1], ipars[idx["shape",1],1], ipars[idx["skew",1],1], distribution)
@@ -883,7 +874,7 @@
 	distribution = model$modeldesc$distribution
 	
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 	kappa = egarchKappa(ipars[idx["ghlambda",1],1], ipars[idx["shape",1],1], ipars[idx["skew",1],1], distribution)
@@ -1029,7 +1020,7 @@
 .egarchpath = function(spec, n.sim = 1000, n.start = 0, m.sim = 1,
 		presigma = NA, prereturns = NA, preresiduals = NA, rseed = NA, 
 		custom.dist = list(name = NA, distfit = NA), mexsimdata = NULL, 
-		vexsimdata = NULL)
+		vexsimdata = NULL, ...)
 {
 	if( (n.sim+n.start) < 20 && m.sim > 100 ){
 		ans = .egarchpath2(spec = spec, n.sim = n.sim, n.start = n.start, m.sim = m.sim,
@@ -1093,7 +1084,7 @@
 	} else { vexdata = NULL }
 	distribution = model$modeldesc$distribution	
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 	
@@ -1252,7 +1243,7 @@
 	distribution = model$modeldesc$distribution
 	
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 	
