@@ -1,7 +1,6 @@
 #################################################################################
 ##
-##   R package rugarch by Alexios Ghalanos Copyright (C) 2008, 2009, 2010, 2011, 
-##	 2012
+##   R package rugarch by Alexios Ghalanos Copyright (C) 2008-2013.
 ##   This file is part of the R package rugarch.
 ##
 ##   The R package rugarch is free software: you can redistribute it and/or modify
@@ -24,7 +23,8 @@
 	eps = .Machine$double.eps
 	
 	# Compute the stepsize (h)
-	h = eps^(1/3)*apply(as.data.frame(x), 1,FUN = function(z) max(abs(z), 1e-2))
+	# h = eps^(1/3)*apply(as.data.frame(x), 1,FUN = function(z) max(abs(z), 1e-4))
+	h = apply(as.data.frame(x), 1,FUN = function(z) max(abs(z)*10e-4, 1e-9))
 	xh = x+h
 	h = xh-x
 	if(length(h) == 1) ee = matrix(h, ncol = 1, nrow = 1) else ee = as.matrix(diag(h))
@@ -55,32 +55,31 @@
 	}
 	return(H)
 }
-# robust standard errors
-.robustSE = function(fun, pars, hess, n, ...)
+.hessian2sidedcpp = function(f, x, ...)
 {
-	stderrors = solve(hess)
-	np = length(pars)	
-	h = apply(as.data.frame(pars), 1, FUN = function(x) min(abs(x/2)+1e-4, max(x,1e-2))*eps^(1/3))
-	hplus =  pars+h
-	hminus = pars-h
-	likelihoodsminus = likelihoodsplus = zeros(n, np)
-	hparsminus = hparsplus = matrix(pars, ncol = np, nrow = np, byrow = T)
-	diag(hparsplus) = hplus
-	diag(hparsminus) = hminus
-	likelihoodsplus =  apply(hparsplus, 1,  FUN = function(x) -fun(x, ...))
-	likelihoodsminus = apply(hparsminus, 1, FUN = function(x) -fun(x, ...))
-	scores = matrix(0, ncol = np, nrow = n)
-	likpm = likelihoodsplus-likelihoodsminus
-	scores = likpm/(2*repmat(t(h), n, 1))
-	scores = apply(scores, 2, FUN = function(x) scale(x, center = TRUE, scale = FALSE))
-	B = (t(scores)%*%scores)
-	robustSE = stderrors%*%B%*%stderrors
-	return(list(scores = scores, robustSE = robustSE))
+	n = length(x)
+	fx = function(y) f(y, ...)
+	eps = .Machine$double.eps
+	# Compute the stepsize (h)
+	#h = eps^(1/3)*apply(as.data.frame(x), 1,FUN = function(z) max(abs(z), 1e-2))
+	# h = eps^(1/3) * sapply(x, FUN = function(z) max(abs(z), 1e-4))
+	h = apply(as.data.frame(x), 1,FUN = function(z) max(abs(z)*1e-4, 1e-9))
+	xh = x+h
+	h = xh-x
+	if(length(h) == 1) ee = matrix(h, ncol = 1, nrow = 1) else ee = as.matrix(diag(h))
+	# Compute forward and backward steps
+	gp = vector(mode = "numeric", length = n)
+	gp = apply(ee, 2, FUN = function(z) f(x+z, ...))
+	gm = vector(mode="numeric",length=n)
+	gm = apply(ee, 2, FUN = function(z) f(x-z, ...))
+	H = h%*%t(h)
+	# Hm = H
+	# Hp = H
+	sol = .Call("hessian2sided", fun = as.function(fx), x = as.numeric(x), H = as.matrix(H), 
+			deps = as.matrix(ee), gminus = as.numeric(gm), gplus = as.numeric(gp), PACKAGE = "rugarch")
+	return(sol)
 }
 
-
-
-
 # The following functions are based on on Kevin Sheppard's MFE toolbox
 #---------------------------------------------------------------------
 neweywestcv = function(data, nlag = NULL, center = TRUE)
@@ -104,8 +103,8 @@ neweywestcv = function(data, nlag = NULL, center = TRUE)
 robustvcv = function(fun, pars, nlag = 0, hess, n, ...)
 {
 	k = length(pars)
-	h = apply(as.data.frame(pars), 1, FUN = function(x) max(abs(x*eps^(1/3)), 1e-7))
-	
+	#h = apply(as.data.frame(pars), 1, FUN = function(x) max(abs(x*eps^(1/3)), 1e-7))
+	h = apply(as.data.frame(pars), 1,FUN = function(z) max(abs(z)*1e-4, 1e-9))
 	hplus =  pars+h
 	hminus = pars-h
 	hparsminus = hparsplus = matrix(pars, ncol = k, nrow = k, byrow = T)
@@ -121,7 +120,7 @@ robustvcv = function(fun, pars, nlag = 0, hess, n, ...)
 	scores = likpm/(2*repmat(t(h), n, 1))
 	A = hess/n
 	hess = A
-	Ainv = try( solve(A, tol = 1e-24), silent = TRUE )
+	Ainv = try( solve(A), silent = TRUE )
 	if( inherits(Ainv, "try-error")){
 		info = 1
 		vcv = NA
