@@ -52,10 +52,10 @@
 	n = length(xdata$data)
 	if((n-n.start)<100) stop("\nugarchfit-->error: function requires at least 100 data\n points to run\n")
 	data = xdata$data[1:(n-n.start)]
-	dates = xdata$pos[1:(n-n.start)]
+	index = xdata$index[1:(n-n.start)]
 	origdata = xdata$data
-	origdates = xdata$pos
-	dformat = xdata$dformat
+	origindex = xdata$index
+	period = xdata$period
 	# arglist replaces the use of custom environments (resolves the problem of 
 	# non-shared environment in parallel estimation, particularly windows)
 	garchenv = new.env(hash = TRUE)
@@ -77,7 +77,7 @@
 	} else{
 		vexdata = NULL
 	}
-	arglist$dates = dates
+	arglist$index = index
 	arglist$trace = trace
 	m =  model$maxOrder
 	# store length of data for easy retrieval
@@ -93,6 +93,12 @@
 	ipars = model$pars
 	# Optimization Starting Parameters Vector & Bounds
 	tmp = .garchstart(ipars, arglist)
+	####################################################
+	# Scale Omega in order to avoid problems: (25-01-2013)
+	#arglist$omegascale = 1/1e8
+	#tmp$ipars["omega",c(1,5,6)] = tmp$ipars["omega",c(1,5,6)]  *1e8
+	####################################################
+	
 	ipars = arglist$ipars = tmp$pars
 	arglist$tmph  = tmp$tmph
 	# we now split out any fixed parameters
@@ -106,7 +112,7 @@
 				# if all parameters are fixed an no standard erros are to
 				# be calculated then we return a ugarchfilter object
 				warning("\nugarchfit-->warning: all parameters fixed...returning ugarchfilter object instead\n")
-				return(ugarchfilter(data = data, spec = spec, out.sample = out.sample))
+				return(ugarchfilter(data = xts(origdata, origindex), spec = spec, out.sample = out.sample))
 			} else{
 				# if all parameters are fixed but we require standard errors, we
 				# skip the solver
@@ -204,8 +210,8 @@
 				hess, arglist = arglist)
 		model$modelinc[7] = modelinc[7]
 		model$modeldata$data = origdata
-		model$modeldata$dates = origdates
-		model$modeldata$date.format = dformat
+		model$modeldata$index = origindex
+		model$modeldata$period = period
 		model$pars[, 1] = fit$ipars[,1]
 		model$pars[, 5:6] = ipars2[,5:6]
 		fit$ipars[, 4] = ipars2[, 4]
@@ -218,8 +224,8 @@
 		fit$message = sol$message
 		fit$convergence = 1
 		model$modeldata$data = origdata
-		model$modeldata$dates = origdates
-		model$modeldata$date.format = dformat
+		model$modeldata$index = origindex
+		model$modeldata$period = period
 	}
 	# make model list to return some usefule information which
 	# will be called by other functions (show, plot, sim etc)
@@ -359,13 +365,13 @@
 	# no forward looking information contaminating the study.
 	xdata = .extractdata(data)
 	data = xdata$data
-	dates = xdata$pos
-	dformat = xdata$dformat
+	index = xdata$index
+	period = xdata$period
 	origdata = data
-	origdates = dates
+	origindex = index
 	T = length(origdata)  - out.sample
 	data = origdata[1:T]
-	dates = origdates[1:T]
+	index = origindex[1:T]
 	if(!is.null(n.old)) Nx = n.old else Nx = length(data)
 	recinit = .checkrec(rec.init, Nx)
 	model = spec@model
@@ -443,8 +449,8 @@
 	filter$distribution = distribution
 	filter$ipars = ipars
 	model$modeldata$data = origdata
-	model$modeldata$dates = origdates
-	model$modeldata$date.format = dformat
+	model$modeldata$index = origindex
+	model$modeldata$period = period
 	model$n.start = out.sample	
 	sol = new("uGARCHfilter",
 			filter = filter,
@@ -473,11 +479,11 @@
 .sgarchforecast = function(fitORspec, data = NULL, n.ahead = 10, n.roll = 0, out.sample = 0, 
 		external.forecasts = list(mregfor = NULL, vregfor = NULL), ...)
 {
-	fit = fitORspec
-	data = fit@model$modeldata$data
-	Nor = length(as.numeric(data))
-	dates = fit@model$modeldata$dates
-	dformat = fit@model$modeldata$date.format
+	fit    = fitORspec
+	data   = fit@model$modeldata$data
+	Nor    = length(as.numeric(data))
+	index  = fit@model$modeldata$index
+	period = fit@model$modeldata$period
 	ns = fit@model$n.start
 	N = Nor - ns
 	model = fit@model
@@ -488,7 +494,7 @@
 	pars = fit@fit$coef
 	ipars = fit@fit$ipars
 	# check if necessary the external regressor forecasts provided first
-	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, ipars, n.ahead, Nor, out.sample = ns, n.roll)
+	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, n.ahead, Nor, out.sample = ns, n.roll)
 	mxf = xreg$mxf
 	vxf = xreg$vxf
 	
@@ -502,15 +508,18 @@
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
 					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]), 
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
-	tmp =  data.frame(data[1:(N + fcreq)])
-	rownames(tmp) = as.character(dates[1:(N + fcreq)])
-	flt = .sgarchfilter(data = tmp[,1,drop=FALSE], spec = fspec, n.old = N)
+	tmp =  xts(data[1:(N + fcreq)], index[1:(N + fcreq)])
+	flt = .sgarchfilter(data = tmp, spec = fspec, n.old = N)
 	sigmafilter = flt@filter$sigma
 	resfilter = flt@filter$residuals
 	zfilter = flt@filter$z
 	# forecast GARCH process
-	forecasts = vector(mode="list", length = n.roll+1)
-	fwdd = vector(mode="list", length = n.roll+1)
+	seriesFor = sigmaFor = matrix(NA, ncol = n.roll+1, nrow = n.ahead)
+	#seriesFor[1,] = fitted(flt)[(N+1):(N+n.roll+1)]
+	#sigmaFor[1,]  = sigma(flt)[(N+1):(N+n.roll+1)]
+	# n.ahead x n.roll +1 (n.ahead=1 generted by model)
+	colnames(seriesFor) = colnames(sigmaFor) = as.character(index[N:(N+n.roll)])
+	rownames(seriesFor) = rownames(sigmaFor) = paste("T+", 1:n.ahead, sep="")
 	for(i in 1:(n.roll+1)){
 		np = N + i - 1
 		if(modelinc[1] > 0){
@@ -518,12 +527,7 @@
 		} else{
 			mu = rep(0, N+i+n.ahead-1)
 		}
-		#if(modelinc[7]>0){
-			omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
-		#} else {
-		#	omega = rep(0, N+i+n.ahead-1)
-		#}
-		# no look-ahead
+		omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
 		h = c(sigmafilter[1:(N+i-1)], rep(0, n.ahead))
 		epsx = c(resfilter[1:(N+i-1)], rep(0, n.ahead))
 		x = c(data[1:(N+i-1)], rep(0, n.ahead))
@@ -532,11 +536,8 @@
 		mxfi = mxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		vxfi = vxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		ans = .nsgarchforecast(ipars, modelinc, idx, mu, omega, mxfi, vxfi, h, epsx, z, data = x, N = np, n.ahead)
-		
-		fdf = data.frame(sigma = ans$h, series = ans$x)
-		fwdd[[i]] = .forcdates( dates, n.ahead, N, i, ns, dformat )
-		rownames(fdf) = as.character(fwdd[[i]])
-		forecasts[[i]] = fdf
+		sigmaFor[,i] = ans$h
+		seriesFor[,i] = ans$x
 	}
 	
 	fcst = list()
@@ -544,8 +545,8 @@
 	fcst$N = N+ns
 	fcst$n.start = ns
 	fcst$n.roll = n.roll
-	fcst$forecasts = forecasts
-	fcst$fdates = fwdd
+	fcst$sigmaFor = sigmaFor
+	fcst$seriesFor = seriesFor
 	model$modeldata$sigma = flt@filter$sigma
 	model$modeldata$residuals = flt@filter$residuals
 	ans = new("uGARCHforecast",
@@ -601,8 +602,8 @@
 	Nor = length(as.numeric(xdata$data))
 	data = xdata$data
 	N = length(as.numeric(data))
-	dates = xdata$pos
-	dformat = xdata$dformat	
+	index = xdata$index
+	period = xdata$period
 	ns = out.sample
 	if( n.roll > ns ) stop("\nugarchforecast-->error: n.roll must not be greater than out.sample!")
 	N = Nor - ns
@@ -626,11 +627,11 @@
 	ipars = model$pars
 	modelinc = model$modelinc
 	model$modeldata$data = data
-	model$modeldata$dates = dates
-	model$modeldata$dformat = dformat
+	model$modeldata$index = index
+	model$modeldata$period = period
 
 	# check if necessary the external regressor forecasts provided first
-	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, ipars, n.ahead, Nor, out.sample = ns, n.roll)
+	xreg = .forcregressors(model, external.forecasts$mregfor, external.forecasts$vregfor, n.ahead, Nor, out.sample = ns, n.roll)
 	mxf = xreg$mxf
 	vxf = xreg$vxf
 	
@@ -644,15 +645,18 @@
 					archm = ifelse(modelinc[5]>0,TRUE,FALSE), archpow = modelinc[5], arfima = modelinc[4], 
 					external.regressors = mxf[1:(N + fcreq), , drop = FALSE], archex = modelinc[20]),
 			distribution.model = model$modeldesc$distribution, fixed.pars = as.list(pars))
-	tmp =  data.frame(data[1:(N + fcreq)])
-	rownames(tmp) = as.character(dates[1:(N + fcreq)])
-	flt = .sgarchfilter(data = tmp[,1,drop=FALSE], spec = fspec, n.old = N)
+	tmp =  xts(data[1:(N + fcreq)], index[1:(N + fcreq)])
+	flt = .sgarchfilter(data = tmp, spec = fspec, n.old = N)
 	sigmafilter = flt@filter$sigma
 	resfilter = flt@filter$residuals
 	zfilter = flt@filter$z
 	# forecast GARCH process
-	forecasts = vector(mode="list", length = n.roll+1)
-	fwdd = vector(mode="list", length = n.roll+1)
+	seriesFor = sigmaFor = matrix(NA, ncol = n.roll+1, nrow = n.ahead)
+	#seriesFor[1,] = fitted(flt)[(N+1):(N+n.roll+1)]
+	#sigmaFor[1,]  = sigma(flt)[(N+1):(N+n.roll+1)]
+	# n.ahead x n.roll +1 (n.ahead=1 generted by model)
+	colnames(seriesFor) = colnames(sigmaFor) = as.character(index[N:(N+n.roll)])
+	rownames(seriesFor) = rownames(sigmaFor) = paste("T+", 1:n.ahead, sep="")
 	for(i in 1:(n.roll+1)){
 		np = N + i - 1
 		if(modelinc[1] > 0){
@@ -660,12 +664,7 @@
 		} else{
 			mu = rep(0, N+i+n.ahead-1)
 		}
-		#if(modelinc[7]>0){
-			omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
-		#} else {
-		#	omega = rep(0, N+i+n.ahead-1)
-		#}
-		# no look-ahead
+		omega = rep(ipars[idx["omega",1]:idx["omega",2], 1], N+i+n.ahead-1)
 		h = c(sigmafilter[1:(N+i-1)], rep(0, n.ahead))
 		epsx = c(resfilter[1:(N+i-1)], rep(0, n.ahead))
 		x = c(data[1:(N+i-1)], rep(0, n.ahead))
@@ -674,26 +673,22 @@
 		mxfi = mxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		vxfi = vxf[1:(N+i-1+n.ahead), , drop = FALSE]
 		ans = .nsgarchforecast(ipars, modelinc, idx, mu, omega, mxfi, vxfi, h, epsx, z, data = x, N = np, n.ahead)
-		
-		fdf = data.frame(sigma = ans$h, series = ans$x)
-		fwdd[[i]] = .forcdates( dates, n.ahead, N, i, ns, dformat )
-		rownames(fdf) = as.character(fwdd[[i]])
-		forecasts[[i]] = fdf
+		sigmaFor[,i] = ans$h
+		seriesFor[,i] = ans$x
 	}
 	fcst = list()
 	fcst$n.ahead = n.ahead
 	fcst$N = N+ns
 	fcst$n.start = ns
 	fcst$n.roll = n.roll
-	fcst$forecasts = forecasts
-	fcst$fdates = fwdd
+	fcst$sigmaFor = sigmaFor
+	fcst$seriesFor = seriesFor
 	model$modeldata$sigma = flt@filter$sigma
 	model$modeldata$residuals = flt@filter$residuals
 	ans = new("uGARCHforecast",
 			forecast = fcst,
 			model = model)
 	return(ans)
-	
 }
 #---------------------------------------------------------------------------------
 # SECTION sGARCH simulate
@@ -701,7 +696,7 @@
 .sgarchsim = function(fit, n.sim = 1000, n.start = 0, m.sim = 1, startMethod = 
 				c("unconditional","sample"), presigma = NA, prereturns = NA, 
 		preresiduals = NA, rseed = NA, custom.dist = list(name = NA, distfit = NA), 
-		mexsimdata = NULL, vexsimdata = NULL)
+		mexsimdata = NULL, vexsimdata = NULL, ...)
 {
 	if( (n.sim+n.start) < 100 && m.sim > 100 ){
 		ans = .sgarchsim2(fit = fit, n.sim = n.sim, n.start = n.start, m.sim = m.sim, 
@@ -749,7 +744,7 @@
 	idx = model$pidx
 	ipars = fit@fit$ipars
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 	
@@ -867,6 +862,7 @@
 			seed = as.integer(sseed))
 	return(sol)
 }
+
 .sgarchsim2 = function(fit, n.sim = 1000, n.start = 0, m.sim = 1, startMethod = 
 				c("unconditional","sample"), presigma = NA, prereturns = NA, 
 		preresiduals = NA, rseed = NA, custom.dist = list(name = NA, distfit = NA), 
@@ -898,7 +894,7 @@
 	idx = model$pidx
 	ipars = fit@fit$ipars
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 	
@@ -1041,7 +1037,7 @@
 .sgarchpath = function(spec, n.sim = 1000, n.start = 0, m.sim = 1,
 		presigma = NA, prereturns = NA, preresiduals = NA, rseed = NA, 
 		custom.dist = list(name = NA, distfit = NA), mexsimdata = NULL, 
-		vexsimdata = NULL)
+		vexsimdata = NULL, ...)
 {
 	if( (n.sim+n.start) < 20 && m.sim > 100 ){
 		ans = .sgarchpath2(spec = spec, n.sim = n.sim, n.start = n.start, m.sim = m.sim,
@@ -1105,7 +1101,7 @@
 	} else { vexdata = NULL }
 	distribution = model$modeldesc$distribution	
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 		
@@ -1257,7 +1253,7 @@
 	distribution = model$modeldesc$distribution
 	
 	# check if necessary the external regressor forecasts provided first
-	xreg = .simregressors(model, mexsimdata, vexsimdata, ipars, N, n, m.sim, m)	
+	xreg = .simregressors(model, mexsimdata, vexsimdata, N, n, m.sim, m)	
 	mexsim = xreg$mexsimlist
 	vexsim = xreg$vexsimlist
 	
